==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/constants/impl/LeafSymbolicConstantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.constants.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.constants.LeafSymbolicConstant;
import io.ciera.tool.sql.ooaofooa.constants.LeafSymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.LiteralSymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.SymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.impl.LiteralSymbolicConstantSetImpl;
import io.ciera.tool.sql.ooaofooa.constants.impl.SymbolicConstantSetImpl;

import java.util.Arrays;
import java.util.List;


public class LeafSymbolicConstantSetImpl extends InstanceSet<LeafSymbolicConstantSet,LeafSymbolicConstant> implements LeafSymbolicConstantSet {

    // attributes
    @Override
    public void setDT_ID_Deprecated( UniqueId m_DT_ID_Deprecated ) throws XtumlException {
        for ( LeafSymbolicConstant leafsymbolicconstant : this ) leafsymbolicconstant.setDT_ID_Deprecated( m_DT_ID_Deprecated );
    }
    @Override
    public void setConst_ID( UniqueId ref_Const_ID ) throws XtumlException {
        for ( LeafSymbolicConstant leafsymbolicconstant : this ) leafsymbolicconstant.setConst_ID( ref_Const_ID );
    }


    // selections
    @Override
    public SymbolicConstantSet R1502_is_a_SymbolicConstant() throws XtumlException {
        SymbolicConstantSet symbolicconstantset = new SymbolicConstantSetImpl();
        for ( LeafSymbolicConstant leafsymbolicconstant : this ) symbolicconstantset.add( leafsymbolicconstant.R1502_is_a_SymbolicConstant() );
        return symbolicconstantset;
    }
    @Override
    public LiteralSymbolicConstantSet R1503_is_a_LiteralSymbolicConstant() throws XtumlException {
        LiteralSymbolicConstantSet literalsymbolicconstantset = new LiteralSymbolicConstantSetImpl();
        for ( LeafSymbolicConstant leafsymbolicconstant : this ) literalsymbolicconstantset.add( leafsymbolicconstant.R1503_is_a_LiteralSymbolicConstant() );
        return literalsymbolicconstantset;
    }


    @Override
    public LeafSymbolicConstant nullElement() {
        return LeafSymbolicConstantImpl.EMPTY_LEAFSYMBOLICCONSTANT;
    }

    @Override
    public LeafSymbolicConstantSet emptySet() {
      return new LeafSymbolicConstantSetImpl();
    }

    @Override
    public LeafSymbolicConstantSet value() {
        return this;
    }

    @Override
    public List<LeafSymbolicConstant> elements() {
        return Arrays.asList(toArray(new LeafSymbolicConstant[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/constants/impl/LeafSymbolicConstantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.constants.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.constants.LeafSymbolicConstant;
import io.ciera.tool.sql.ooaofooa.constants.LeafSymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.LiteralSymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.SymbolicConstantSet;
import io.ciera.tool.sql.ooaofooa.constants.impl.LiteralSymbolicConstantSetImpl;
import io.ciera.tool.sql.ooaofooa.constants.impl.SymbolicConstantSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LeafSymbolicConstantSetImpl extends InstanceSet<LeafSymbolicConstantSet,LeafSymbolicConstant> implements LeafSymbolicConstantSet {

    public LeafSymbolicConstantSetImpl() {
    }

    public LeafSymbolicConstantSetImpl(Comparator<? super LeafSymbolicConstant> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDT_ID_Deprecated( UniqueId m_DT_ID_Deprecated ) throws XtumlException {
        for ( LeafSymbolicConstant leafsymbolicconstant : this ) leafsymbolicconstant.setDT_ID_Deprecated( m_DT_ID_Deprecated );
    }
    @Override
    public void setConst_ID( UniqueId ref_Const_ID ) throws XtumlException {
        for ( LeafSymbolicConstant leafsymbolicconstant : this ) leafsymbolicconstant.setConst_ID( ref_Const_ID );
    }


    // selections
    @Override
    public SymbolicConstantSet R1502_is_a_SymbolicConstant() throws XtumlException {
        SymbolicConstantSet symbolicconstantset = new SymbolicConstantSetImpl();
        for ( LeafSymbolicConstant leafsymbolicconstant : this ) symbolicconstantset.add( leafsymbolicconstant.R1502_is_a_SymbolicConstant() );
        return symbolicconstantset;
    }
    @Override
    public LiteralSymbolicConstantSet R1503_is_a_LiteralSymbolicConstant() throws XtumlException {
        LiteralSymbolicConstantSet literalsymbolicconstantset = new LiteralSymbolicConstantSetImpl();
        for ( LeafSymbolicConstant leafsymbolicconstant : this ) literalsymbolicconstantset.add( leafsymbolicconstant.R1503_is_a_LiteralSymbolicConstant() );
        return literalsymbolicconstantset;
    }


    @Override
    public LeafSymbolicConstant nullElement() {
        return LeafSymbolicConstantImpl.EMPTY_LEAFSYMBOLICCONSTANT;
    }

    @Override
    public LeafSymbolicConstantSet emptySet() {
      return new LeafSymbolicConstantSetImpl();
    }

    @Override
    public LeafSymbolicConstantSet emptySet(Comparator<? super LeafSymbolicConstant> comp) {
      return new LeafSymbolicConstantSetImpl(comp);
    }

    @Override
    public LeafSymbolicConstantSet value() {
        return this;
    }

    @Override
    public List<LeafSymbolicConstant> elements() {
        return Arrays.asList(toArray(new LeafSymbolicConstant[0]));
    }

}
